now

Function now 

pub fn now() -> u64
Returns the current time as milliseconds since Unix epoch.

Returns

Milliseconds since January 1, 1970 00:00:00 UTC. Returns 0 if system time is before the Unix epoch (should not happen on properly configured systems).

Example

use logicaffeine_system::time;

let timestamp = time::now();
assert!(timestamp > 0);